==> haskell-parsers-0.12.11-116-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-parsers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 parsers
version:              0.12.11
visibility:           public
id:                   parsers-0.12.11-KKZCd67Ne3jJeBuhqWF0up
key:                  parsers-0.12.11-KKZCd67Ne3jJeBuhqWF0up
license:              BSD-3-Clause
copyright:            Copyright (C) 2010-2013 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            experimental
homepage:             http://github.com/ekmett/parsers/
synopsis:             Parsing combinators
description:
    This library provides convenient combinators for working with and building parsing combinator libraries.

    Given a few simple instances, e.g. for the class '\''Text.Parser.Combinators.Parsing'\'' in "Text.Parser.Combinators.Parsing" you
    get access to a large number of canned definitions. Instances exist for the parsers provided by @parsec@,
    @attoparsec@ and base’s "Text.Read".

category:             Text, Parsing
abi:                  86d59c4e940b0c0a2c0374abebeac0dd
exposed:              True
exposed-modules:
    Text.Parser.Char Text.Parser.Combinators Text.Parser.Expression
    Text.Parser.LookAhead Text.Parser.Permutation Text.Parser.Token
    Text.Parser.Token.Highlight Text.Parser.Token.Style

import-dirs:          /usr/lib/ghc-9.2.8/site-local/parsers-0.12.11
library-dirs:         /usr/lib/ghc-9.2.8/site-local/parsers-0.12.11
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-parsers
hs-libraries:         HSparsers-0.12.11-KKZCd67Ne3jJeBuhqWF0up
depends:
    attoparsec-0.14.4-Bi4fbguKdku98LXMy0bDoK base-4.16.4.0
    base-orphans-0.8.8.2-6ve0eRw4Ula2nCJtGYIJNG binary-0.8.9.0
    charset-0.3.10-9ygnYyfUN7L7PQVHkzEP0 containers-0.6.5.1 mtl-2.2.2
    parsec-3.1.15.0 scientific-0.3.7.0-72r9rPpXaeUjwM4XNBSJR
    text-1.2.5.0 transformers-0.5.6.2
    unordered-containers-0.2.20-8WFaf62MVyiL1uC2m0h0zY

haddock-interfaces:   /usr/share/doc/haskell-parsers/html/parsers.haddock
haddock-html:         /usr/share/doc/haskell-parsers/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-parsers-0.12.11-117-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-parsers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 parsers
version:              0.12.11
visibility:           public
id:                   parsers-0.12.11-AIxozg5J78DL2yZJRGeRdI
key:                  parsers-0.12.11-AIxozg5J78DL2yZJRGeRdI
license:              BSD-3-Clause
copyright:            Copyright (C) 2010-2013 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            experimental
homepage:             http://github.com/ekmett/parsers/
synopsis:             Parsing combinators
description:
    This library provides convenient combinators for working with and building parsing combinator libraries.

    Given a few simple instances, e.g. for the class '\''Text.Parser.Combinators.Parsing'\'' in "Text.Parser.Combinators.Parsing" you
    get access to a large number of canned definitions. Instances exist for the parsers provided by @parsec@,
    @attoparsec@ and base’s "Text.Read".

category:             Text, Parsing
abi:                  78d56ce14b7a4742596fffaad2d67289
exposed:              True
exposed-modules:
    Text.Parser.Char Text.Parser.Combinators Text.Parser.Expression
    Text.Parser.LookAhead Text.Parser.Permutation Text.Parser.Token
    Text.Parser.Token.Highlight Text.Parser.Token.Style

import-dirs:          /usr/lib/ghc-9.2.8/site-local/parsers-0.12.11
library-dirs:         /usr/lib/ghc-9.2.8/site-local/parsers-0.12.11
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-parsers
hs-libraries:         HSparsers-0.12.11-AIxozg5J78DL2yZJRGeRdI
depends:
    attoparsec-0.14.4-Bi4fbguKdku98LXMy0bDoK base-4.16.4.0
    base-orphans-0.8.8.2-6ve0eRw4Ula2nCJtGYIJNG binary-0.8.9.0
    charset-0.3.10-FXD2zsj09QQHWr2xZdNjdB containers-0.6.5.1 mtl-2.2.2
    parsec-3.1.15.0 scientific-0.3.7.0-72r9rPpXaeUjwM4XNBSJR
    text-1.2.5.0 transformers-0.5.6.2
    unordered-containers-0.2.20-B4pxT3iF0jR7WvKg6foz6h

haddock-interfaces:   /usr/share/doc/haskell-parsers/html/parsers.haddock
haddock-html:         /usr/share/doc/haskell-parsers/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
